/**
 ** wylkeys.h ---- Keyboard Translation Table
 **
 ** Copyright (C) 2024 Mariano Alvarez Fernandez
 ** [e-mail: malfer@telefonica.net]
 **
 ** This file is part of the GRX graphics library.
 **
 ** The GRX graphics library is free software; you can redistribute it
 ** and/or modify it under some conditions; see the "copying.grx" file
 ** for details.
 **
 ** This library is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 **
 **/

#ifndef _WYLKEYS_H_
#define _WYLKEYS_H_

typedef struct {
  unsigned short key;
  unsigned int keywyl;
} KeyEntry;

static KeyEntry _KTAlt[] = { // state == Alt
  { GrKey_Alt_0                , KEY_0 },
  { GrKey_Alt_1                , KEY_1 },
  { GrKey_Alt_2                , KEY_2 },
  { GrKey_Alt_3                , KEY_3 },
  { GrKey_Alt_4                , KEY_4 },
  { GrKey_Alt_5                , KEY_5 },
  { GrKey_Alt_6                , KEY_6 },
  { GrKey_Alt_7                , KEY_7 },
  { GrKey_Alt_8                , KEY_8 },
  { GrKey_Alt_9                , KEY_9 },
  { GrKey_Alt_A                , KEY_A },
  { GrKey_Alt_B                , KEY_B },
  { GrKey_Alt_C                , KEY_C },
  { GrKey_Alt_D                , KEY_D },
  { GrKey_Alt_E                , KEY_E },
  { GrKey_Alt_F                , KEY_F },
  { GrKey_Alt_G                , KEY_G },
  { GrKey_Alt_H                , KEY_H },
  { GrKey_Alt_I                , KEY_I },
  { GrKey_Alt_J                , KEY_J },
  { GrKey_Alt_K                , KEY_K },
  { GrKey_Alt_L                , KEY_L },
  { GrKey_Alt_M                , KEY_M },
  { GrKey_Alt_N                , KEY_N },
  { GrKey_Alt_O                , KEY_O },
  { GrKey_Alt_P                , KEY_P },
  { GrKey_Alt_Q                , KEY_Q },
  { GrKey_Alt_R                , KEY_R },
  { GrKey_Alt_S                , KEY_S },
  { GrKey_Alt_T                , KEY_T },
  { GrKey_Alt_U                , KEY_U },
  { GrKey_Alt_V                , KEY_V },
  { GrKey_Alt_W                , KEY_W },
  { GrKey_Alt_X                , KEY_X },
  { GrKey_Alt_Y                , KEY_Y },
  { GrKey_Alt_Z                , KEY_Z },
  { GrKey_Alt_Escape           , KEY_ESC },
  { GrKey_Alt_Return           , KEY_ENTER },
  { GrKey_Alt_Tab              , KEY_TAB },
  { GrKey_Alt_Backspace        , KEY_BACKSPACE },
  { GrKey_Alt_Delete           , KEY_DELETE },
  { GrKey_Alt_Down             , KEY_DOWN },
  { GrKey_Alt_End              , KEY_END },
  { GrKey_Alt_F1               , KEY_F1 },
  { GrKey_Alt_F2               , KEY_F2 },
  { GrKey_Alt_F3               , KEY_F3 },
  { GrKey_Alt_F4               , KEY_F4 },
  { GrKey_Alt_F5               , KEY_F5 },
  { GrKey_Alt_F6               , KEY_F6 },
  { GrKey_Alt_F7               , KEY_F7 },
  { GrKey_Alt_F8               , KEY_F8 },
  { GrKey_Alt_F9               , KEY_F9 },
  { GrKey_Alt_F10              , KEY_F10 },
  { GrKey_Alt_F11              , KEY_F11 },
  { GrKey_Alt_F12              , KEY_F12 },
  { GrKey_Alt_Home             , KEY_HOME },
  { GrKey_Alt_Insert           , KEY_INSERT },
  { GrKey_Alt_Left             , KEY_LEFT },
  { GrKey_Alt_PageDown         , KEY_PAGEDOWN },
  { GrKey_Alt_PageUp           , KEY_PAGEUP },
  { GrKey_Alt_Right            , KEY_RIGHT },
  { GrKey_Alt_Up               , KEY_UP },
/*
  { GrKey_Alt_At               , XK_at },
  { GrKey_Alt_Center           , XK_KP_Begin },
  { GrKey_Alt_Delete           , XK_KP_Delete },
  { GrKey_Alt_Home             , XK_KP_Home },
  { GrKey_Alt_Insert           , XK_KP_Insert },
  { GrKey_Alt_KPMinus          , XK_KP_Subtract },
  { GrKey_Alt_KPPlus           , XK_KP_Add },
  { GrKey_Alt_KPSlash          , XK_KP_Divide },
  { GrKey_Alt_KPStar           , XK_KP_Multiply },
  { GrKey_Alt_KPStar           , XK_multiply },
  { GrKey_Alt_Left             , XK_KP_Left },
  { GrKey_Alt_PageDown         , XK_KP_Next },
  { GrKey_Alt_PageUp           , XK_KP_Prior },
  { GrKey_Alt_Right            , XK_KP_Right },
  { GrKey_Alt_Up               , XK_KP_Up },
  { GrKey_Alt_Down             , XK_KP_Down },
  { GrKey_Alt_End              , XK_KP_End },
  { GrKey_Alt_Enter            , XK_KP_Enter },
  { GrKey_Alt_Backquote        , XK_quoteright },
  { GrKey_Alt_Backslash        , XK_backslash },
  { GrKey_Alt_Comma            , XK_comma },
  { GrKey_Alt_Dash             , XK_minus },
  { GrKey_Alt_Equals           , XK_equal },
  { GrKey_Alt_LAngle           , XK_less },
  { GrKey_Alt_LBrace           , XK_braceleft },
  { GrKey_Alt_LBracket         , XK_bracketleft },
  { GrKey_Alt_Period           , XK_period },
  { GrKey_Alt_Pipe             , XK_bar },
  { GrKey_Alt_Quote            , XK_quoteleft },
  { GrKey_Alt_RAngle           , XK_greater },
  { GrKey_Alt_RBrace           , XK_braceright },
  { GrKey_Alt_RBracket         , XK_bracketright },
  { GrKey_Alt_Semicolon        , XK_semicolon },
  { GrKey_Alt_Slash            , XK_slash },
*/
};


static KeyEntry _KTShift[] = { // state == Shift
  { GrKey_BackTab              , KEY_TAB },
  { GrKey_Shift_Down           , KEY_DOWN },
  { GrKey_Shift_End            , KEY_END },
  { GrKey_Shift_F1             , KEY_F1 },
  { GrKey_Shift_F2             , KEY_F2 },
  { GrKey_Shift_F3             , KEY_F3 },
  { GrKey_Shift_F4             , KEY_F4 },
  { GrKey_Shift_F5             , KEY_F5 },
  { GrKey_Shift_F6             , KEY_F6 },
  { GrKey_Shift_F7             , KEY_F7 },
  { GrKey_Shift_F8             , KEY_F8 },
  { GrKey_Shift_F9             , KEY_F9 },
  { GrKey_Shift_F10            , KEY_F10 },
  { GrKey_Shift_F11            , KEY_F11 },
  { GrKey_Shift_F12            , KEY_F12 },
  { GrKey_Shift_Home           , KEY_HOME },
  { GrKey_Shift_Insert         , KEY_INSERT },
  { GrKey_Shift_Left           , KEY_LEFT },
  { GrKey_Shift_PageDown       , KEY_PAGEDOWN },
  { GrKey_Shift_PageUp         , KEY_PAGEUP },
  { GrKey_Shift_Right          , KEY_RIGHT },
  { GrKey_Shift_Up             , KEY_UP },
};


static KeyEntry _KTControl[] = { // state == Control
  { GrKey_Control_Delete       , KEY_DELETE },
  { GrKey_Control_Down         , KEY_DOWN },
  { GrKey_Control_End          , KEY_END },
  { GrKey_Control_F1           , KEY_F1 },
  { GrKey_Control_F2           , KEY_F2 },
  { GrKey_Control_F3           , KEY_F3 },
  { GrKey_Control_F4           , KEY_F4 },
  { GrKey_Control_F5           , KEY_F5 },
  { GrKey_Control_F6           , KEY_F6 },
  { GrKey_Control_F7           , KEY_F7 },
  { GrKey_Control_F8           , KEY_F8 },
  { GrKey_Control_F9           , KEY_F9 },
  { GrKey_Control_F10          , KEY_F10 },
  { GrKey_Control_F11          , KEY_F11 },
  { GrKey_Control_F12          , KEY_F12 },
  { GrKey_Control_Home         , KEY_HOME },
  { GrKey_Control_Insert       , KEY_INSERT },
  { GrKey_Control_Left         , KEY_LEFT },
  { GrKey_Control_PageDown     , KEY_PAGEDOWN },
  { GrKey_Control_PageUp       , KEY_PAGEUP },
  { GrKey_Control_Right        , KEY_RIGHT },
  { GrKey_Control_Up           , KEY_UP },
/*
  { GrKey_Control_At           , XK_at },
  { GrKey_Control_Center       , XK_5 },
  { GrKey_Control_Center       , XK_KP_Begin },
  { GrKey_Control_Delete       , XK_KP_Delete },
  { GrKey_Control_Down         , XK_KP_Down },
  { GrKey_Control_End          , XK_KP_End },
  { GrKey_Control_Home         , XK_KP_Home },
  { GrKey_Control_Insert       , XK_KP_Insert },
  { GrKey_Control_KPDash       , XK_KP_Subtract },
  { GrKey_Control_KPPlus       , XK_KP_Add },
  { GrKey_Control_KPSlash      , XK_slash },
  { GrKey_Control_KPStar       , XK_multiply },
  { GrKey_Control_Left         , XK_KP_Left },
  { GrKey_Control_PageDown     , XK_KP_Next },
  { GrKey_Control_PageUp       , XK_KP_Prior },
  { GrKey_Control_Right        , XK_KP_Right },
  { GrKey_Control_Up           , XK_KP_Up },
*/
};

static KeyEntry _KTVoid[] = { // state == None
  { GrKey_Delete               , KEY_DELETE },
  { GrKey_Down                 , KEY_DOWN },
  { GrKey_End                  , KEY_END },
  { GrKey_F1                   , KEY_F1 },
  { GrKey_F2                   , KEY_F2 },
  { GrKey_F3                   , KEY_F3 },
  { GrKey_F4                   , KEY_F4 },
  { GrKey_F5                   , KEY_F5 },
  { GrKey_F6                   , KEY_F6 },
  { GrKey_F7                   , KEY_F7 },
  { GrKey_F8                   , KEY_F8 },
  { GrKey_F9                   , KEY_F9 },
  { GrKey_F10                  , KEY_F10 },
  { GrKey_F11                  , KEY_F11 },
  { GrKey_F12                  , KEY_F12 },
  { GrKey_Home                 , KEY_HOME },
  { GrKey_Insert               , KEY_INSERT },
  { GrKey_Left                 , KEY_LEFT },
  { GrKey_PageDown             , KEY_PAGEDOWN },
  { GrKey_PageUp               , KEY_PAGEUP },
  { GrKey_Right                , KEY_RIGHT },
  { GrKey_Up                   , KEY_UP },
/*
  { GrKey_Center               , XK_5 },
  { GrKey_Center               , XK_KP_Begin },
  { GrKey_Dash                 , XK_KP_Subtract },
  { GrKey_Delete               , XK_KP_Delete },
  { GrKey_Down                 , XK_KP_Down },
  { GrKey_End                  , XK_KP_End },
  { GrKey_Home                 , XK_KP_Home },
  { GrKey_Insert               , XK_KP_Insert },
  { GrKey_Left                 , XK_KP_Left },
  { GrKey_PageDown             , XK_KP_Next },
  { GrKey_PageUp               , XK_KP_Prior },
  { GrKey_Plus                 , XK_KP_Add },
  { GrKey_Print                , XK_Print },
  { GrKey_Right                , XK_KP_Right },
  { GrKey_Up                   , XK_KP_Up },
*/
};

#endif
